#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 knob
version:              0.2.2
visibility:           public
id:                   knob-0.2.2-C6uO4qMQKGWIGLfyGFLrbG
key:                  knob-0.2.2-C6uO4qMQKGWIGLfyGFLrbG
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/ncfavier/knob
synopsis:             Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.

    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)

category:             System
abi:                  e91c15536cc7f0fb66e58b7fd4dae4d1
exposed:              True
exposed-modules:      Data.Knob
import-dirs:          /usr/lib/ghc-9.6.6/site-local/knob-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/knob-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/knob-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-knob
hs-libraries:         HSknob-0.2.2-C6uO4qMQKGWIGLfyGFLrbG
depends:
    base-4.18.2.1 bytestring-0.11.5.3 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html:         /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

